document.addEventListener('DOMContentLoaded', () => {
  // Theme Toggle
  const themeToggle = document.getElementById('themeToggle');
  const prefersDark = window.matchMedia('(prefers-color-scheme: dark)');
  
  function setTheme(isDark) {
    document.documentElement.setAttribute('data-theme', isDark ? 'dark' : 'light');
    themeToggle.textContent = isDark ? '☀️' : '🌑';
  }
  
  setTheme(prefersDark.matches);
  
  themeToggle.addEventListener('click', () => {
    const isDark = document.documentElement.getAttribute('data-theme') === 'dark';
    setTheme(!isDark);
  });

  // Confidence Meters Animation
  const aiMeter = document.getElementById('aiMeter');
  const cryptoMeter = document.getElementById('cryptoMeter');
  
  setTimeout(() => {
    aiMeter.style.width = '85%';
    cryptoMeter.style.width = '65%';
  }, 500);

  // Investment Calculator
  const calculator = {
    aiReturn: 0.15, // 15% annual return
    cryptoReturn: 0.25, // 25% annual return
    cryptoVolatility: 0.5, // 50% volatility
    
    calculate(initial, years) {
      const aiValue = initial * Math.pow(1 + this.aiReturn, years);
      const cryptoValue = initial * Math.pow(1 + this.cryptoReturn, years);
      const cryptoLow = cryptoValue * (1 - this.cryptoVolatility);
      const cryptoHigh = cryptoValue * (1 + this.cryptoVolatility);
      
      return {
        ai: aiValue.toFixed(2),
        cryptoLow: cryptoLow.toFixed(2),
        cryptoHigh: cryptoHigh.toFixed(2)
      };
    }
  };

  const calculateBtn = document.getElementById('calculate');
  const results = document.getElementById('results');
  
  calculateBtn.addEventListener('click', () => {
    const investment = parseFloat(document.getElementById('investment').value);
    const years = parseInt(document.getElementById('years').value);
    
    if (investment && years) {
      const returns = calculator.calculate(investment, years);
      results.innerHTML = `
        <h3>Projected Returns After ${years} Years:</h3>
        <p>AI Investment: $${returns.ai}</p>
        <p>Crypto Investment Range:</p>
        <p>Low: $${returns.cryptoLow}</p>
        <p>High: $${returns.cryptoHigh}</p>
      `;
    }
  });
});
